@@ -31,3 +31,22 @@ import qualified MegaModule as M (
     (<<<),
     (>>>),
  )
+
+{- // -}
+
+-- https://github.com/fourmolu/fourmolu/issues/341
+module Foo (
+    -- | asdf
+    singleExport,
+) where
+
+{- // -}
+
+-- https://github.com/fourmolu/fourmolu/issues/381
+module Foo (
+    -- * Re-export of module
+    module X,
+
+    -- * Some other thing
+    Foo,
+) where
